.layout-container, .page-container, .page-container > div, body, html {
    height: 100%;
    width: 100%;
}
body{
    color: #555;
    font-size: 14px;
}
body p{
    line-height: 20px;
}
a{
    color: #000;
    text-decoration: none
}
a:hover {
    color: #005580;
    text-decoration: none
}
.container{
    width: 96%;
    margin: 0 auto;
    min-width: 1200px;
}
footer{
    clear:both;
    color: #898989;
    font-size: 14px;
}
footer p:first-of-type{
    float: left;
}
footer p:last-of-type{
    float: right;
}
footer a{
    color: #08c;
    text-decoration: none;
}
footer a:hover {
    color: #005580;
    text-decoration: underline;
}
h1{
    font-size: 33px;
    font-weight: normal;
    line-height: 40px;
    margin: 0;
}
hr{
    width: 100%;
    height: 3px;
    border-top: 2px solid #555;
    margin: 12px 0 20px;
}
.main-container{
    margin-left: 260px;
}
.header-container {
    margin-left: 260px;
    position: relative;
    z-index: 1;
    background-color: #1976d2;
}
.main-container > section {
    min-height: calc(100% - 60px);
}
.content{
    width: 100%;
    box-sizing: border-box;
    padding: 40px;
    float: left;
    margin: 0
}
input, textarea{
    border-radius: 0 !important;
}
.form-actions {
    background-color: transparent;
    border-top: none;
}
.dashboard{
    width: 100%;
    background: #f1f1f1;
    border: 1px solid #ddd;
    margin-bottom: 15px;
    float: left;
}
.head_dashboard{
    width: 100%;
    float: left;
    border-bottom: 1px solid #e2e2e2;
    background: #f6f6f6;
}
.head_dashboard li{
    float: left;
    height: 35px;
    line-height: 35px;
    border-right: 1px solid #e2e2e2;
    padding: 0 15px
}
.cont_dashboard{
    border-top: 1px solid #fff;
    width: 100%;
    float: left;
}
.cont_dashboard p{
    padding: 15px 20px;
}
/*----------------------------------------header------------------------------------*/
.layout-container{
    position: relative;
}
.header-container > nav {
    box-shadow: 0 0 1px 1px rgba(0, 0, 0, 0.14);
    line-height: 45px;
    min-height: 45px;
}
.header-container > nav > .header-title {
    float: left;
    font-size: 18px;
    font-weight: 400;
    letter-spacing: 0.02em;
    line-height: 45px;
    margin: 0 0 0 7px;
    position: relative;
    color: #fff;
    width: 24%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}
.header-container nav .menu-link {
    height: 32px;
    color: inherit;
    display: block;
    padding: 13px 16px 0;
    text-decoration: none;
    color: #fff;
}
.header-container nav .menu-link:hover{
    background: rgba(0, 0, 0, 0.05)
}
.header-container nav .dropdown-menu li > a {
    white-space: inherit;
}
.header-container nav .dropdown-submenu.pull-left > .dropdown-menu {
    left: -246px;
    width: 235px;
}
.header-container nav .dropdown-menu li > a:hover, .dropdown-menu li > a:focus, .dropdown-submenu:hover > a{
    background: #1976d2
}
.menu-link-close span, .menu-link-close span::after, .menu-link-close span::before {
    border-bottom: 2px solid;
    height: 0;
    transition: transform 0.4s ease 0s;
    width: 18px;
    will-change: transform;
}
.menu-link-close span {
    transition: border-color 0.4s ease 0s;
}
.menu-link-close span::after, .menu-link-close span::before {
    content: " ";
    position: absolute;
}
.menu-link-slide, .menu-link-slide span {
    display: block;
    position: relative;
}
.menu-link-close span::before {
    top: 6px;
}
.menu-link-close span::after {
    top: 12px;
}
.active .menu-link-close span {
    border-color: transparent;
}
.active .menu-link-close span::before {
    transform: rotate(45deg) translate(1px, 0px);
}
.active .menu-link-close span::after {
    transform: rotate(-45deg) translate(4px, -3px);
}
.menu-link-slide span, .menu-link-slide span::after, .menu-link-slide span::before {
    border-bottom: 2px solid;
    height: 0;
    transition: all 0.4s ease 0s;
    width: 18px;
}
.menu-link-slide span::after, .menu-link-slide span::before {
    content: " ";
    position: absolute;
}
.menu-link-slide span::before {
    left: 0;
    top: 7px;
    width: 60%;
    will-change: left;
}
.menu-link-slide span::after {
    top: 14px;
}
.menu-link-slide em {
    border-bottom: 4px solid transparent;
    border-left: 4px solid;
    border-top: 4px solid transparent;
    height: 0;
    position: absolute;
    right: 0;
    top: 4px;
    transition: all 0.4s ease 0s;
    width: 0;
    will-change: right, transform;
}
.menu-link-arrow, .menu-link-arrow span {
    display: block;
    position: relative;
}
.active .menu-link-slide span::before {
    left: 40%;
}
.active .menu-link-slide span em {
    right: 80%;
    transform: rotate(180deg);
}
.menu-link-arrow span {
    height: 14px;
    transition: transform 0.4s ease 0s;
    width: 18px;
    will-change: transform;
}
.menu-link-arrow em, .menu-link-arrow em::after, .menu-link-arrow em::before {
    border-bottom: 2px solid;
    content: " ";
    display: block;
    height: 0;
    position: absolute;
    transition: transform 0.4s ease 0s;
    width: 18px;
    will-change: transform;
}
.menu-link-arrow em {
    transition: border-color 0.4s ease 0s;
}
.menu-link-arrow em::before {
    top: -6px;
}
.menu-link-arrow em, .menu-link-arrow em::after {
    top: 6px;
}
.active .menu-link-arrow span {
    transform: rotate(180deg);
}
.active .menu-link-arrow span em::before {
    transform: translateX(6px) translateY(1px) rotate(45deg);
    width: 12px;
}
.active .menu-link-arrow span em::after {
    transform: translateX(6px) translateY(-1px) rotate(-45deg);
    width: 12px;
}
.header-container > nav > ul > li {
    float: left;
    list-style-type: none
}
.header-container > nav > ul > li > a {
    color: inherit;
    display: block;
    padding: 0 16px;
    text-decoration: none;
    color: #fff;
    font-size: 28px;
}
.header-container > nav > ul .dropdown-menu li > span{
    padding: 3px 20px;
    white-space: nowrap;
    color: #333;
    display: block;
    font-weight: normal;
    line-height: 20px;
}
.header-container .dropdown-menu .fa{
    color: #aaa;
    float: left;
    margin: 3px 10px 0 0;
}
.header-container .user_profile{
    margin: 7px 25px 0 0;
}
.header-container .dropdown-menu{
    min-width: 220px;
}
.header-container .dropdown-menu-right {
    left: auto;
    right: 0;
}
.header-container .dropdown-menu li > a:hover{
    background: #263238
}
.header-container .dropdown-menu a:hover .fa{
    color: #fff
}
.header-container .dropdown-toggle {
    margin: 0;
}
#dLabel:hover{
    background: transparent
}
/*-------------------------------------------sidebar---------------------------------*/
.sidebar-container {
    background-color: #263238;
    bottom: 0;
    color: rgba(255, 255, 255, 0.75);
    left: 0;
    overflow-x: visible;
    overflow-y: auto;
    position: fixed;
    top: 0;
    width: 260px;
    will-change: transform;
    z-index: 20;
    padding: 0
}
.sidebar-nav {
    background-color: inherit;
    font-weight: 500;
    padding-bottom: 30px
}
.sidebar-nav ul {
    list-style-type: none;
    margin: 0;
    padding: 0;
}
.sidebar-container a.sb-link {
    color: rgba(255, 255, 255, 0.75);
    text-decoration: none;
}
.sidebar-header {
    box-shadow: 0 0 1px 1px rgba(0, 0, 0, 0.14);
    height: 65px;
    padding: 0 16px;
}
.sidebar-header > span {
    color: #fff;
    font-size: 20px;
    line-height: 65px;
}
.sidebar-header + .sidebar-content {
    height: calc(100% - 65px);
    overflow: auto;
}
.sidebar-content {
    border-right: 1px solid rgba(0, 0, 0, 0.11);
}
.sidebar-nav .panel-heading{
    padding: 0
}
.sidebar-nav .panel-heading a, .sidebar-nav .panel-collapse.collapse.in{
    background-color: rgba(162, 162, 162, 0.027);
}
.sidebar-nav .panel-heading a.collapsed{
    background: transparent
}
.sidebar-nav .list-item a {
    color: inherit;
    display: block;
    height: 50px;
    letter-spacing: 0.0125em;
    line-height: 50px;
    overflow: hidden;
    padding: 0 16px;
    text-decoration: none;
    font-size: 14px;
    font-weight: 300
}
.sidebar-nav .list-item a:hover{
    color: #fff;
}
.sidebar-nav .list-item.active ul {
    height: auto;
}
.sidebar-nav .list-item ul li a {
    margin-left: 0;
    opacity: 1;
    height: 40px;
    line-height: 40px;
}
.sidebar-nav .list-item ul li a span{
    white-space: nowrap;
    display: block;
}
.sidebar-nav .list-item ul li a {
    padding: 0 0 0 40px;
}
.sidebar-nav li.active a{
    color: #fff
}
.sidebar-nav .list-item a i{
    margin: 0 5px 0 0;
    font-size: 16px;
    color: #75a5d5
}
.sidebar-nav a i.fa-angle-down{
    color: #fff;
    float: right;
    font-size: 14px;
    height: 50px;
    line-height: 50px;
    margin: 0;
    opacity: 0.5;
    transition: transform 0.2s ease 0s;
    display: none
}
.sidebar-nav a.collapsed i.fa-angle-down{
    transform: rotate(-90deg);
}
.accordion-group {
    border: none;
    border-radius: 0;
    margin-bottom: 0;
}
.sidebar-nav .list-item a[href="#"] i.fa-angle-down{
    display: block
}
/*-------------------------------------------logo---------------------------------*/
.logo_sidebar{
    background: url("/assets/components/ciext/img/logo.png") center center no-repeat;
    background-size: contain;
    width: 100%;
    height: 45px;
    float: left;
    margin: 10px 0 0
}
/*-------------------------------------------btn---------------------------------*/
.dropdown-menu li > a:hover{
    background: #1976d2
}
input.btn[type="submit"]{
    border-radius: 4px !important;
}
.btn-primary, .btn-success, .btn.remove, .btn.btn-danger{
    box-shadow: none;
    text-shadow: none;
    color: #fff;
}
.btn{
    background: #fff;
    border-color: #ddd
}
.btn:hover{
    background: #f5f5f5;
    border-color: #ddd
}
.btn-primary{
    background: #1976d2;
    border-color: #1976d2
}
.btn-primary:hover{
    background: #1e84e9;
    border-color: #1e84e9
}
.btn-success {
    background: #5bb75b;
    border-color: #5bb75b
}
.btn-success:hover {
    background: #49ae49;
    border-color: #49ae49
}
input[type="radio"], input[type="checkbox"] {
    margin: -3px 0 0;
}
.btn.active {
    background: #5bb75b;
    color: #fff;
    box-shadow: none !important;
    border-color: #5bb75b;
    text-shadow: none
}
.btn.active + .btn{
    z-index: 0
}
.btn.remove, .btn.btn-danger{
    background: #ea4d4d;
    border-color: #ea4d4d
}
.btn.remove:hover, .btn.btn-danger:hover{
    background: #da2f2f;
    border-color: #da2f2f
}
/*-------------------------------------------seo---------------------------------*/
.seo-content .indent {
    padding: 20px 0;
}
.seo-content td:first-of-type {
    width: 140px;
}
.seo-content td {
    text-align: left;
    vertical-align: central;
}
.seo-content h5 {
    line-height: 40px;
}
.seo-content input[type="text"] {
    width: 100%;
}
.seo-content textarea {
    max-width: none;
    min-width: 0;
    width: 100% !important;
}
/*------------------------------------------form---------------------------------*/
.form-horizontal .control-label {
    text-align: left
}
.form-horizontal .form-actions {
    padding-left: 0;
}
/*----------------------------------------logo size---------------------------------*/
.error503 .logo, .error404 .logo{
    background: url("../img/logo.png") no-repeat center center !important;
}
header .logo{
    background: url("../img/logo.png") center 22px no-repeat, white !important;
}
.radio input[type="radio"], .checkbox input[type="checkbox"] {
  float: left;
  margin: 3px 0 0 -20px;
}
table td{
    padding: 8px;
}