$(function() {
    var container = $('.content');
    var from = 0;
    var send = false;
    $(window).scroll(function() {
        var h = container.height();
        var y = $(window).scrollTop();
        if (y > (h * .65) && y < (h * .75)) {
            if (!send) {
                send = true;
                from += 20;
                $.post('ajax/ciext/admin/get_more', {from: from}, function(html) {
                    if (html != '') {
                        container.append(html);
                        send = false;
                    }
                });
            }
        }
    });
});