<form id="install_form" action="" method="post">
    <div class="control-group">
        <label class="control-label" for="inputlanguage_short">{ln_language}</label>
        <div class="controls">
            <select name="language_short">
                {languages}
                <option value="{key}" {selected} >{value}</option>
                {/languages}
            </select>
        </div>
    </div>
    {items}
    <div class="control-group">
        <label class="control-label" for="input{name}">{ln_name}</label>
        <div class="controls">
            <input type="text" id="{name}" value="{value}" name="{name}">
        </div>
    </div>
    {/items}
    <div class="form-actions">
        <button type="submit" class="btn btn-success">{ln_btn_next}</button>
    </div>
</form>
<script type="text/javascript">
    $(function(){
        $("#install_form").validate({
            rules: {
                encryption_key: 'required',
                super_user_login: 'required',
                super_user_pass: 'required',
                super_user_cpass: {
                    equalTo: "input[name=super_user_pass]"
                },
                admin_page: 'required'
            }
        });
    })

</script>