<div id="admin-menu">
    <div id="amenu-content">
        <div class="amenu-content">
            <div id="amenu-search">
                <form id="amenu-search-form" action="" method="post" class="search">
                    <input id="amenu-search-input" type="search" name="" placeholder="{search_text}" class="input" />
                </form>
            </div>
            <div id="amenu-search-result">
                <div class="amenu-block">
                    <div class="amenu-block-head">                        
                        <label>{search_title}</label>
                    </div>
                    <ul class="amenu-block-content">

                    </ul>
                </div>
            </div>

            <div id="amenu-default">
                {blocks}
                <div class="amenu-block">
                    <div class="amenu-block-head">
                        <label>{block_title}</label>
                        <a class="amenu-block-toggle" href="" onclick="return false;" style="display: none;">down</a>
                    </div>
                    <ul class="amenu-block-content">
                        {block_items}
                        <li class="amenu-item-drag" rel="{id_admin_menu}" title="{translate}">
                            <a href="{page}">
                                <img src="{image}" alt="{translate}" title="{translate}" />
                                <span>{translate}</span>
                            </a>
                        </li>
                        {/block_items}
                    </ul>
                </div>
                {/blocks}
            </div>
        </div>
    </div>
</div>