<?php

if (!defined('BASEPATH'))
    exit('No direct script access allowed');

/**
 * Description of filemanager
 *
 * @author Igor Ratsun
 */
class filemanager extends \Ciext\Controller\AbstractAdminController {

    public function index() {
        $this->load->library('ciext/admin_lib');
        // Unset left menu
        $this->admin_lib->content['user_left_menu'] = '';
        // Set top menu active
        $this->admin_lib->content['active_menu'] = 3;

        $this->admin_lib->show(array(
            'content' => '<iframe style="height:600px; width:100%" src="'.base_url().'assets/plugins/kcfinder/browse.php?type=images&CKEditor=news_1&CKEditorFuncNum=2&langCode=ru"></iframe>'
        ));
    }

}

