<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Return data from configurator
 *
 * @author Igor Ratsun
 */
class parser_configurator
{

    public function parse($acl_resource, $conf_key)
    {
        get_instance()->load->library('ciext/configurator');
        $cnf = new configurator($acl_resource);
        
        return $cnf->item($conf_key);
    }

}
