<?php 

$lang['title'] = 'Modules install/uninstall';

$lang['module_installed'] = 'Installed';
$lang['module_removed'] = 'Uninstalled';

$lang['ln_install'] = 'Install';
$lang['ln_remove'] = 'Uninstall';

$lang['res_name'] = 'Module';
$lang['res_alias'] = 'Alias';

$lang['msg_install'] = 'Install the module ';
$lang['msg_uninstall'] = 'Uninstall the module ';

$lang['Return to list'] = '< Return to list';

$lang['Remove module from ACL'] = 'Remove module from ACL';
$lang['Drop module tables'] = 'Drop module tables';
$lang['Module was installed'] = 'Module was installed';
$lang['Module was removed'] = 'Module was removed';