<?php

namespace Ciext\Controller;

abstract class AbstractAuthController extends \MX_Controller
{

    public function __construct()
    {
        parent::__construct();

        if (empty($this->rt_user->id_user)) {
            $this->show_sign_in();
        }
    }

    public static function show_sign_in()
    {
        $_error = & load_class('Exceptions', 'core');
        echo $_error->show_error('403', get_instance()->lang->line('Please, sign in'), 'error_403', 403);
        exit;
    }

}
